@@ -364,6 +364,11 @@ class CustomerAdmin(ModelAdmin):
     readonly_fields = ('created', 'created_by', 'updated', 'updated_by')
 
 
+class DepartmentUserInline(admin.TabularInline):
+
+    model = models.DepartmentUser
+
+
 class DepartmentAdmin(ModelAdmin):
 
     fieldsets = (
@@ -378,11 +383,37 @@ class DepartmentAdmin(ModelAdmin):
                        'updated_by'
                        )}),
     )
+    #inlines = [DepartmentUserInline]
     list_display = ('id', 'name', 'created', 'updated')
     list_display_links = ('id', 'name')
     readonly_fields = ('created', 'created_by', 'updated', 'updated_by')
 
 
+class DepartmentUserForm(forms.ModelForm):
+    """Form validation for :class:`DepartmentUserAdmin`"""
+
+    class Meta:
+        model = models.DepartmentUser
+
+    def clean(self, *args, **kwds):
+        data = self.cleaned_data
+        query = models.DepartmentUser.objects.filter(
+            user=data['user'], department=data['department'])
+        if query.count() == 1 and self.instance.pk is None:
+            raise forms.ValidationError(
+                'The user "%s" is already a member in the department "%s".'
+                % (data['user'], data['department']))
+        return data
+
+
+class DepartmentUserAdmin(ModelAdmin):
+
+    form = DepartmentUserForm
+    list_filter = ['department', 'user']
+    list_display = ('id', 'department', 'user')
+    list_display_links = ('id',)
+
+
 class HardwareAdmin(ModelAdmin):
 
     list_display = ('id', 'name', 'manufacturer', 'group', 'model',
@@ -464,6 +495,7 @@ class ProjectForm(forms.ModelForm):
 
 class ProjectAdmin(ModelAdmin):
 
+    date_hierarchy = 'created'
     fieldsets = (
         (None, {
             'fields': ('name',
@@ -471,6 +503,7 @@ class ProjectAdmin(ModelAdmin):
                        'type',
                        'status',
                        'master',
+                       'department',
                        )}),
         (_(u'Customer'), {
             'fields': ('customer',
@@ -492,10 +525,11 @@ class ProjectAdmin(ModelAdmin):
     list_display = ('id', 'name', 'customer', 'type', 'colored_status',
                     'created', 'updated')
     list_display_links = ('id', 'name')
-    list_filter = ['status', 'type', 'customer']
+    list_filter = ['status', 'type', 'customer', 'department']
     ordering = ['id']
     raw_id_fields = ['customer', 'contact']
     readonly_fields = ('created', 'created_by', 'updated', 'updated_by')
+    search_fields = ['name', 'description']
 
     def colored_status(self, project):
         if project.status.id in (models.PROJECT_STATUS_CLOSED,
@@ -510,6 +544,15 @@ class ProjectAdmin(ModelAdmin):
     colored_status.admin_order_field = 'status'
     colored_status.short_description = _(u'Status')
 
+    def queryset(self, request):
+        query = super(ProjectAdmin, self).queryset(request)
+        if request.user.is_superuser:
+            return query
+        # If the user is not an administrator, filter the project list
+        # by his department assignments.
+        departments = models.Department.objects.get_by_user(request.user)
+        ids = [dep.id for dep in departments]
+        return query.filter(department__id__in=ids)
 
     def save_model(self, request, obj, form, change):
         # Create a self reference if no master is given
@@ -765,7 +808,7 @@ admin.site.register(models.Customer, CustomerAdmin)
 # Day
 # DefaultProject
 admin.site.register(models.Department, DepartmentAdmin)
-# DepartmentUser
+admin.site.register(models.DepartmentUser, DepartmentUserAdmin)
 admin.site.register(models.Hardware, HardwareAdmin)
 admin.site.register(models.HardwareGroup, HardwareGroupAdmin)
 admin.site.register(models.HardwareUser, HardwareUserAdmin)
