@@ -187,7 +187,7 @@ def issue(request):
         kwargs = {'%s__contains' % property: query}
         issues = Issue.objects.filter(**kwargs)
         issues = issues.filter(tracker=tracker)
-        issues = issues.order_by('no')
+        issues = issues.order_by('-no')
         for issue in issues:
             if issue.id in added:
                 continue
