@@ -9,6 +9,10 @@ import re
 
 from django import template
 from django.contrib.auth.models import User
+
+from django.template.defaultfilters import truncatewords
+
+
 from django.core.cache import cache
 from django.forms import BaseForm, Form
 from django.forms.forms import NON_FIELD_ERRORS
@@ -20,6 +24,19 @@ from models import Account, Booking
 
 register = template.Library()
 
+
+
+@register.filter
+def duration_to_pixel(val):
+    """Convert a booking duration to pixel dimension.
+
+    :param val: A :class:`Decimal` value
+
+    :returns: An integer
+    """
+    return int(val / 2)
+
+
 @register.filter
 def format_errors(form, non_field_msg=_(u'General errors')):
     class FormError: object
@@ -77,13 +94,10 @@ def show_booking_link(booking_id):
     if ret is None:
         logging.debug("Missing cache entry for booking:%d", booking_id)
         booking = Booking.get_by_id(booking_id)
-        if booking.is_closed():
-            cls = 'disabled'
-        else:
-            cls = ''
-        ret = ("""<a class="%(class)s" onmouseover="JS_showInfoPopup(this, 'bookingPopupDiv', 'edit',
+        title = cgi.escape(truncatewords(booking.get_title(), 5))
+        ret = ("""<a onmouseover="JS_showInfoPopup(this, 'bookingPopupDiv', 'edit',
         '/booking_popup/')" href="/time/edit/%(id)d">%(title)s</a>"""
-               % {'id': booking.id, 'title': cgi.escape(booking.get_title()), 'class': cls})
+               % {'id': booking.id, 'title': title})
         cache.set('booking:%d' % booking_id, ret)
     return mark_safe(ret)
 
