@@ -12,6 +12,20 @@ class CustomerManager(Manager):
     pass
 
 
+class DepartmentManager(Manager):
+
+    def get_by_user(self, user):
+        """Returns the user`s departments.
+
+        :param user: A :class:`User` model
+
+        :returns: A query object
+        """
+        query = models.Department.objects.filter(
+            departmentuser__user=user)
+        return query
+
+
 class NewsManager(Manager):
 
     def get_current(self):
