@@ -202,6 +202,9 @@ class Account(User):
         query = query.order_by('created')
         return query
 
+    def is_project_manager(self):
+        pass
+
     def works_for_customer(self, customer):
         query = ProjectUser.objects.filter(user=self)
         query = query.filter(project__customer=customer)
@@ -569,8 +572,8 @@ class Booking(Model):
     def next_position(self):
         """Set the next available position, depending on the day."""
         bookings = Booking.objects.filter(day=self.day)
-        self.position = bookings.aggregate(models.Max('position'))[
-            'position__max'] or 0 + 1
+        self.position = (bookings.aggregate(models.Max('position'))[
+            'position__max'] or 0) + 1
 
     def revert(self, history):
         """Copy values from a history instance.
@@ -1074,11 +1077,16 @@ class Department(Model):
     updated = models.DateTimeField(db_column='abt_upddate',
                                    verbose_name=_(u'Updated'))
 
+    objects = managers.DepartmentManager()
+
     class Meta:
         db_table = u'abteilung'
         verbose_name = _(u'Department')
         verbose_name_plural = _(u'Departments')
 
+    def __unicode__(self):
+        return self.name
+
 
 class DepartmentUser(Model):
 
