@@ -44,7 +44,6 @@ urlpatterns += patterns(
     (r'^dashboard$', 'dashboard'),
     (r'^dashboard/starred$', 'starred_bookings'),
     (r'^(\d+)/pause_timer$', 'pause_timer'),
-    (r'^overview$', 'overview'),
     (r'^profile$', 'edit_profile'),
     (r'^projects$', 'show_projects'),
     (r'^(\d+)/remove_timer$', 'remove_timer'),
@@ -52,12 +51,16 @@ urlpatterns += patterns(
     (r'^(\d+)/star_booking$', 'star_booking'),
     (r'^(\d+)/start_timer$', 'start_timer'),
     (r'^time$', 'time'),
-    (r'^time/edit/(\d+)$', 'edit_booking'),
-    (r'^time/history/(\d+)$', 'show_history'),
-    (r'^time/undo$', 'undo_booking_change'),
     (r'^time/(?P<year>\d{4})/(?P<month>\d{1,2})/(?P<day>\d+)/$', 'show_day'),
     (r'^time/(?P<year>\d{4})/(?P<month>\d{1,2})/(?P<day>\d+)/new$', 'new_booking'),
+    (r'^time/edit/(\d+)$', 'edit_booking'),
+    (r'^time/history/(\d+)$', 'show_history'),
+    (r'^time/overview$', 'overview'),
     (r'^time/today$', 'show_today'),
+    (r'^time/tomorrow$', 'show_tomorrow'),
+    (r'^time/undo$', 'undo_booking_change'),
+    (r'^time/week$', 'show_week'),
+    (r'^time/yesterday$', 'show_yesterday'),
     (r'^(\d+)/unstar_booking$', 'unstar_booking'),
     (r'^user/(\d+)$', 'show_user'),
     (r'^edit_timer$', 'edit_timer'),
