@@ -72,6 +72,7 @@ def respond(request, template, params=None):
     params['is_dev'] = True
     #params['debug'] = DEBUG
     params['debug'] = True
+
     full_path = request.get_full_path().encode('utf-8')
     #if request.user is None:
         #params['sign_in'] = users.create_login_url(full_path)
@@ -423,11 +424,14 @@ def show_day(request, year=None, month=None, day=None):
         date = datetime.date(int(year), int(month), int(day))
     except ValueError:
         return HttpResponseNotFound()
+    _prev = date - datetime.timedelta(days=1)
+    _next = date + datetime.timedelta(days=1)
     day = request.user.account.get_day(date)
     bookings = models.Booking.objects.select_related().filter(
         day=day).order_by('position')
-    return respond(request, 'day.html', {'date': date, 'bookings': bookings,
-                                         'day': day})
+    return respond(request, 'day.html', {
+        'date': date, 'bookings': bookings, 'day': day, 'prev_date': _prev,
+        'next_date': _next})
 
 
 def _revert_booking(request, history_id):
@@ -490,6 +494,13 @@ def show_projects(request):
     return respond(request, 'projects.html', {'projects': projects})
 
 
+@login_required
+def show_yesterday(request):
+    date = datetime.date.today() - datetime.timedelta(days=1)
+    return HttpResponseRedirect(reverse('inhouse.views.show_day',
+                                        args=[date.year, date.month,
+                                              date.day]))
+
 @login_required
 def show_today(request):
     """Redirect to the current date."""
@@ -497,6 +508,15 @@ def show_today(request):
     return HttpResponseRedirect(reverse('inhouse.views.show_day',
                                         args=[date.year, date.month,
                                               date.day]))
+
+@login_required
+def show_tomorrow(request):
+    date = datetime.date.today() + datetime.timedelta(days=1)
+    return HttpResponseRedirect(reverse('inhouse.views.show_day',
+                                        args=[date.year, date.month,
+                                              date.day]))
+
+
 @login_required
 def show_user(request, user_id):
     """Displays the public user information.
@@ -506,8 +526,39 @@ def show_user(request, user_id):
     user = User.objects.filter(id=user_id)[0]
     projects = models.Project.objects.get_by_user(
         user, active_only=False).order_by('name')
-    return respond(request, 'user.html', {'user_to_show': user,
-                                          'projects': projects})
+    departments = models.Department.objects.get_by_user(user).order_by('name')
+    return respond(request, 'user.html', {
+        'user_to_show': user,
+        'projects': projects,
+        'departments': departments})
+
+
+@login_required
+def show_week(request):
+    days = []
+    day_data = []
+    sum_data = []
+    today = datetime.date.today()
+    week_day = today.weekday()
+    first_day = today - datetime.timedelta(days=week_day)
+    last_day = today + datetime.timedelta(days=7 - (week_day + 1))
+    for n in xrange(0, 7):
+        date = first_day + datetime.timedelta(days=n)
+        days.append(date)
+        day_data.append([])
+        x = request.user.account.get_day(date)
+        sum_data.append(x.get_booking_sum())
+    bookings = models.Booking.objects.select_related().filter(
+        day__user=request.user,
+        day__date__gte=first_day,
+        day__date__lte=last_day)
+    bookings = bookings.order_by('position')
+    for booking in bookings:
+        day_data[booking.day.date.weekday()].append(booking)
+    return respond(request, 'week.html', {
+        'days': days, 'day_data': day_data,
+        'first_day': first_day, 'last_day': last_day,
+        'sum_data': sum_data})
 
 
 @post_required
