@@ -1,8 +1,15 @@
 // remap jQuery to $
 (function($){
-  $(".default-table tr").mouseover(function() {$(this).addClass("over");}).mouseout(function() {$(this).removeClass("over");});
+  $(".default-table tr").mouseover(function() {
+      if ( !$(this).hasClass("sum") ) {
+        $(this).addClass("over");
+      }
+    }).mouseout(function() {
+      $(this).removeClass("over");
+    });
   $(".default-table tr:even").addClass("alt");
   $(".timer-table tr").mouseover(function() {$(this).addClass("over");}).mouseout(function() {$(this).removeClass("over");});
+  $(".timeline-list li").mouseover(function() {$(this).addClass("over");}).mouseout(function() {$(this).removeClass("over");});
 })(window.jQuery);
 
 
