@@ -198,18 +198,15 @@ function JS_fillDropdown(element, data, first_label, field) {
 }
 
 function JS_shortcutHandler(evt) {
-  return M_keyPressCommon(evt, function(evt, src, code, key)
-    {
-      // TODO: g+x event handling
-      if (key == 'd') {
-	log('d', this);
-	//document.location.href = '/dashboard';
+  return M_keyPressCommon(evt, function(evt, src, code, key) {
+	if (key == 'd') {
+	  document.location.href = '/dashboard';
       } else if (key == 'v') {
-	JS_gotoNextDay();
+	document.location.href = '/time/tomorrow';
       } else if (key == 'c') {
-	JS_gotoCurrentDay();
+	document.location.href = '/time/today';
       } else if (key == 'x') {
-	JS_gotoPreviousDay();
+	document.location.href = '/time/yesterday';
       } else if (key == '+') {
 	JS_addTimer();
       } else if (key == '\r' || key == '\n') {
@@ -221,25 +218,6 @@ function JS_shortcutHandler(evt) {
     }, JS_inputShortcutHandler);
 }
 
-function JS_gotoPreviousDay() {
-  var url = window.location.pathname;
-  var index = url.indexOf("/day");
-  var day = url.substring(index + 5);
-  window.location.href = '/previous_day/' + day;
-}
-
-function JS_gotoCurrentDay() {
-  var today = new Date();
-  window.location.href = '/time/' + today.getFullYear() + '/' + (today.getMonth() + 1) + '/' + today.getDate();
-}
-
-function JS_gotoNextDay() {
-  var url = window.location.pathname;
-  var index = url.indexOf("/day");
-  var day = url.substring(index + 5);
-  window.location.href = '/next_day/' + day;
-}
-
 /**
  * Call a star function
  * @param {id} Id of the booking entry
@@ -467,4 +445,83 @@ function JS_editTimerMessage(timer_id, title) {
 function JS_applyTimer(timer_id) {
   var today = new Date();
   window.location.href = "/time/" + today.getFullYear() + '/' + (today.getMonth() + 1) + '/' + today.getDate() + '/new?timer_id=' + timer_id;
-}
\ No newline at end of file
+}
+
+/**
+ * (De)Select all checkboxes within a table
+ * @param {String} id Id of the table element
+ * @param {Boolean} value Whether to check or uncheck the input
+ */
+function JS_toggleTableCheckboxes(id, value) {
+  var table = document.getElementById(id);
+  var inputs = table.getElementsByTagName('input');
+  //var first_checked = null;
+  for (i = 0; i < inputs.length; i++) {
+	var e = inputs[i];
+	/*
+	if (e.parentNode != 'td') {
+	  continue;
+	}
+	*/
+	if (e.type && e.type.toLowerCase() == 'checkbox') {
+  		e.checked = value;
+	  /*
+	  if (first_checked == null) {
+		  if (e.checked == true) {
+			  e.checked = false;
+		  }
+		  else {
+			  e.checked = true;
+		  }
+		  first_checked = e.checked;
+	  }
+	  else {
+		  e.checked = first_checked;
+	  }
+	  */
+	}
+  }
+}
+
+function JS_expandAllTimelines(id) {
+  var table = document.getElementById(id);
+  var divs = table.getElementsByTagName('div');
+  for (i = 0; i < divs.length; i++) {
+	var e = divs[i];
+	if (e.className == 'details') {
+	  e.style.display = '';
+	}
+  }
+  var spans = table.getElementsByTagName('span');
+  for (i = 0; i < spans.length; i++) {
+    var e = spans[i];
+	if (e.className == 'sprite plus') {
+	  e.className = 'sprite minus';
+	}
+	else if (e.id.match(/^.*short-description$/)) {
+	  e.style.display = 'none';
+	}
+  }
+}
+
+function JS_collapseAllTimelines(id) {
+  var table = document.getElementById(id);
+  var divs = table.getElementsByTagName('div');
+  for (i = 0; i < divs.length; i++) {
+	var e = divs[i];
+	if (e.className == 'details') {
+	  e.style.display = 'none';
+	}
+  }
+  var spans = table.getElementsByTagName('span');
+  for (i = 0; i < spans.length; i++) {
+    var e = spans[i];
+	if (e.className == 'sprite minus') {
+	  e.className = 'sprite plus';
+	}
+	else if (e.id.match(/^.*short-description$/)) {
+	  e.style.display = '';
+	}
+  }
+
+}
